#!/usr/bin/python

import sys
from optparse import OptionParser
from whiffle import wikidotapi

def dotag(api, page, tag, remove):
	if remove:
		removetag(api, page, tag)
	else:
		addtag(api, page, tag)
		
def addtag(api, page, tag):
	print "Adding tag '"+tag+"' to '"+page+"'"
	try:
		api.add_tag(page, tag, ErrorIfRedundant=False)
	except Exception as e:
		print "Error (", page, "add", tag,"): ", e

def removetag(api, page, tag):
	print "Removing tag '"+tag+"' from '"+page+"'"
	try:
		api.remove_tag(page, tag, ErrorIfRedundant=False)
	except Exception as e:
		print "Error (", page, "remove", tag,"): ", e

parser = OptionParser(usage="%prog [options] page [tag]\nAdds or removes tags from Wikidot pages.")
parser.disable_interspersed_args()
parser.add_option("-i", "--identity",
                  action="store", dest="identity", default="default",
                  help="define the name of the entry in the identity.ini file to use. The default is 'default'.")
parser.add_option("-r", "--remove",
                  action="store_true", dest="remove", default=False,
                  help="remove the specified tag (default action is to add it).")
parser.add_option("-f", "--file",
                  action="store", dest="filename", default=None,
                  help="define the name of the a file, each line of which contains <page>SPACE<tag> or just <page>. "+
		  "If <tag> is not specified on any line, then the one specified on the command line is used. "+
		  "If every line specifies a tag, then a tag is not required on the command line.", metavar="FILE")
(options, args) = parser.parse_args()

if options.filename==None:
	if len(args) < 2:
		parser.error("page and tag arguments are required unless a file is specified.")
		sys.exit(1)
	else:
		page = args[0]
		tag = args[1]
		f = None
else:
	f = open (options.filename, "r")

	if len(args) < 1:
		page = None
		tag = None
	else:
		page = None
		tag = args[0]


api = wikidotapi.connection(options.identity)

if f == None:
	dotag(api, page, tag, options.remove)
else:
	i = 0
	for l in f:
		i = i + 1
		words = l.split()
		if len(words) == 2:
			dotag(api, words[0], words[1], options.remove)
		elif len(words) == 1:
			if tag == None:
				print "Line", i,"does not contain a tag, and no tag is specified on the command line"
				sys.exit(1)
			dotag(api, words[0], tag, options.remove)
		elif len(words) != 0:
			print "Line", i,"does not contain either a page and a tag or just a page"
			sys.exit(1)




#!/usr/bin/python

import sys
from optparse import OptionParser
from whiffle import wikidotapi

def chparent(api, parent,child):
	print "Changing parent of '"+child+"' to '"+parent+"'"
	try:
		api.set_page_item(child, "parent_page", parent)
	except Exception as e:
		print "Error (", parent, child,"): ", e

parser = OptionParser(usage="%prog [options] parent child\n")
parser.disable_interspersed_args()
parser.add_option("-i", "--identity",
                  action="store", dest="identity", default="default",
                  help="Define the name of the wikidot user with permission to make the required change.")
parser.add_option("-f", "--file",
                  action="store", dest="filename", default=None,
                  help="define the name of the operations file", metavar="FILE")
(options, args) = parser.parse_args()

if options.filename==None:
	if len(args) < 2:
		parser.error("parent and child arguments are required.")
		sys.exit(1)
	else:
		f = None
else:
	f = open (options.filename, "r")

api = wikidotapi.connection(options.identity)

if f == None:
	chparent(api, args[0],args[1])
else:
	for l in f:
		p = l.find(" ")
		child = l[p+1:-1]
		parent = l[:p]
		chparent(api, parent,child)

#print "Done"




from distutils.core import setup

setup(
    name='Whiffle',
    version='0.1.0',
    packages=['whiffle',],
    license='GNU Lesser General Public License v3 or later',
    description='A wrapper around the Wikidot XML-RPC API',
    long_description=open('README.txt').read(),
    author="Richard Urwin",
    author_email="soronlin.voyage+whiffle@googlemail.com",
    url="http://www.soronlin.org.uk/software:whiffle",
)

